==> tutti-ui-swing-0.2-sources.jar: fr/ifremer/tutti/ui/swing/util/table/MoveToPreviousEditableRowAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: MoveToPreviousEditableRowAction.java 30 2012-12-06 17:03:05Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/MoveToPreviousEditableRowAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTable;
import java.awt.event.ActionEvent;

/**
 * Action to select previous editable row in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MoveToPreviousEditableRowAction<M extends AbstractTuttiTableModel> extends AbstractSelectTableAction<M> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(MoveToPreviousEditableRowAction.class);

    public static <M extends AbstractTuttiTableModel> MoveToPreviousEditableRowAction<M> newAction(M model, JTable table) {
        return new MoveToPreviousEditableRowAction<M>(model, table);
    }

    protected MoveToPreviousEditableRowAction(M model, JTable table) {
        super(model, table);
    }

    @Override
    public void actionPerformed(ActionEvent e) {

        int currentRow = getSelectedRow();
        int currentColumn = getSelectedColumn();

        if (isCellEditable(currentRow, currentColumn)) {
            if (log.isDebugEnabled()) {
                log.debug("Move to previous row editable cell " +
                          getCellCoordinate(currentRow, currentColumn));
            }
            currentRow--;

            if (currentRow < 0) {
                if (log.isDebugEnabled()) {
                    log.debug("No previous row");
                }
            } else {
                doSelectCell(currentRow, currentColumn);
            }
        } else {
            if (log.isDebugEnabled()) {
                log.debug("Cell not editable at " +
                          getCellCoordinate(currentRow, currentColumn));
            }
        }
    }
}

==> tutti-ui-swing-0.2.5-sources.jar: fr/ifremer/tutti/ui/swing/util/table/MoveToPreviousEditableRowAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: MoveToPreviousEditableRowAction.java 30 2012-12-06 17:03:05Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.2.5/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/MoveToPreviousEditableRowAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JTable;
import java.awt.event.ActionEvent;

/**
 * Action to select previous editable row in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MoveToPreviousEditableRowAction<M extends AbstractTuttiTableModel> extends AbstractSelectTableAction<M> {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(MoveToPreviousEditableRowAction.class);

    public static <M extends AbstractTuttiTableModel> MoveToPreviousEditableRowAction<M> newAction(M model, JTable table) {
        return new MoveToPreviousEditableRowAction<M>(model, table);
    }

    protected MoveToPreviousEditableRowAction(M model, JTable table) {
        super(model, table);
    }

    @Override
    public void actionPerformed(ActionEvent e) {

        int currentRow = getSelectedRow();
        int currentColumn = getSelectedColumn();

        if (isCellEditable(currentRow, currentColumn)) {
            if (log.isDebugEnabled()) {
                log.debug("Move to previous row editable cell " +
                          getCellCoordinate(currentRow, currentColumn));
            }
            currentRow--;

            if (currentRow < 0) {
                if (log.isDebugEnabled()) {
                    log.debug("No previous row");
                }
            } else {
                doSelectCell(currentRow, currentColumn);
            }
        } else {
            if (log.isDebugEnabled()) {
                log.debug("Cell not editable at " +
                          getCellCoordinate(currentRow, currentColumn));
            }
        }
    }
}
